summaryrefslogtreecommitdiffstats
path: root/src/components/Quote.vue
diff options
context:
space:
mode:
Diffstat (limited to 'src/components/Quote.vue')
-rw-r--r--src/components/Quote.vue8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/components/Quote.vue b/src/components/Quote.vue
index 9338fe10a..988be27cb 100644
--- a/src/components/Quote.vue
+++ b/src/components/Quote.vue
@@ -20,7 +20,7 @@
-->
<docs>
-This component is intended to be used both in `NewMessageForm` and `Message`
+This component is intended to be used both in `NewMessage` and `Message`
components.
</docs>
@@ -47,7 +47,7 @@ components.
<p>{{ shortenedQuoteMessage }}</p>
</blockquote>
</div>
- <div v-if="isNewMessageFormQuote" class="quote__main__right">
+ <div v-if="isNewMessageQuote" class="quote__main__right">
<NcButton type="tertiary"
:aria-label="cancelQuoteLabel"
@click="handleAbortReply">
@@ -125,10 +125,10 @@ export default {
default: '',
},
/**
* If the quote component is used in the `NewMessageForm` component we display
* the remove button.
*/
- isNewMessageFormQuote: {
+ isNewMessageQuote: {
type: Boolean,
default: false,
},
@@ -125,10 +125,10 @@ export default {
},
/**
- * If the quote component is used in the `NewMessageForm` component we display
+ * If the quote component is used in the `NewMessage` component we display
* the remove button.
*/